aboutsummaryrefslogtreecommitdiffstats
path: root/pkg
diff options
context:
space:
mode:
Diffstat (limited to 'pkg')
-rw-r--r--pkg/stats/syzbotstats/bug.go7
1 files changed, 5 insertions, 2 deletions
diff --git a/pkg/stats/syzbotstats/bug.go b/pkg/stats/syzbotstats/bug.go
index 11e97fac1..c11274583 100644
--- a/pkg/stats/syzbotstats/bug.go
+++ b/pkg/stats/syzbotstats/bug.go
@@ -8,14 +8,17 @@ import "time"
type BugStatSummary struct {
Title string
IDs []string // IDs used by syzbot for this bug.
+ FirstTime time.Time // When the bug was first hit.
ReleasedTime time.Time // When the bug was published.
ReproTime time.Time // When we found the reproducer.
CauseBisectTime time.Time // When we found cause bisection.
ResolvedTime time.Time // When the bug was resolved.
Status BugStatus
Subsystems []string
- Strace bool // Whether we managed to reproduce under strace.
- HitsPerDay float64 // Average number of bug hits per day.
+ Strace bool // Whether we managed to reproduce under strace.
+ HitsPerDay float64 // Average number of bug hits per day.
+ FixHashes []string // Hashes of fix commits.
+ HappenedOn []string // Managers on which the crash happened.
}
type BugStatus string